#
# spec file for package nextcloud
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


#
%if 0%{?suse_version}
%define apache_serverroot /srv/www/htdocs
%define apache_confdir /etc/apache2/conf.d
%define apache_docdir /usr/share/doc/packages
%define apache_user wwwrun
%define apache_group www
%else
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
%define apache_serverroot /var/www/html
%define apache_confdir /etc/httpd/conf.d
%define apache_user apache
%define apache_group apache
%define __jar_repack 0
%else
%define apache_serverroot /var/www
%define apache_confdir /etc/httpd/conf.d
%define apache_user www
%define apache_group www
%endif
%endif

%define oc_user 	%{apache_user}
%define oc_dir  	%{apache_serverroot}/%{name}
%define ocphp_bin	/usr/bin

%if 0%{?rhel} == 600 || 0%{?rhel_version} == 600 || 0%{?centos_version} == 600
%define statedir	/var/run
%else
%define statedir	/run
%endif
Name:           nextcloud
%define base_version 11.0.3
Version:        %{base_version}
Release:        3.1
Summary:        File hosting service
License:        AGPL-3.0
Group:          Productivity/Networking/Web/Utilities
Url:            http://www.nextcloud.com
Source0:        https://download.nextcloud.com/server/releases/%{name}-%{version}.tar.bz2
Source1:        apache_secure_data
Source2:        README
Source3:        README.SELinux
Source4:        robots.txt
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%if 0%{?suse_version}
BuildRequires:  apache2 >= 2.4
%if 0%{?suse_version} > 1020
BuildRequires:  fdupes
%endif
BuildRequires:  unzip
%endif
#
Requires:       curl
Requires:       mysql
Requires:       php-gd
Requires:       php-json
Requires:       php-mbstring
Requires:       php-mysql
Requires:       php-posix
Requires:       php-zip
#
%if 0%{?fedora_version} || 0%{?rhel} || 0%{?rhel_version} || 0%{?centos_version}
Requires:       php >= 5.6.0
Requires:       php-process
Requires:       php-xml
#
Recommends:     sqlite
%endif
#
%if 0%{?suse_version}
Requires:       apache2
Requires:       mod_php_any >= 5.6.0
Requires:       php-ctype
Requires:       php-curl
# SUSE does not include the fileinfo module in php-common.
Requires:       php-fileinfo
Requires:       php-iconv
Requires:       php-openssl
Requires:       php-pear
Requires:       php-xmlreader
Requires:       php-xmlwriter
Requires:       php-zlib
#
Recommends:     sqlite3
%endif
#
Recommends:     php-imagick 
Recommends:     php-sqlite

%description
Nextcloud is a suite of client-server software for creating file
hosting services and using them.

%prep
%setup -q -n %{name}
cp %{SOURCE2} .
cp %{SOURCE3} .
cp %{SOURCE4} .
#%%patch0 -p0

%build

%install
# no server side java code contained, alarm is false
idir=$RPM_BUILD_ROOT/%{apache_serverroot}/%{name}
mkdir -p $idir
mkdir -p $idir/data
mkdir -p $idir/search
cp -aRf * $idir
cp -aRf .htaccess $idir
cp -aRf .user.ini $idir
# $idir/l10n to disappear in future
#rm -f $idir/l10n/l10n.pl

if [ ! -f $idir/robots.txt ]; then
  install -p -D -m 644 %{SOURCE4} $idir/robots.txt
fi

# create the AllowOverride directive
install -p -D -m 644 %{SOURCE1} $RPM_BUILD_ROOT/%{apache_confdir}/nextcloud.conf
ocpath="%{apache_serverroot}/%{name}"
sed -i -e"s|@DATAPATH@|${ocpath}|g" $RPM_BUILD_ROOT/%{apache_confdir}/nextcloud.conf

# not needed for distro packages
rm -f ${idir}/indie.json

%if 0%{?suse_version}
# link duplicate doc files
%fdupes -s $RPM_BUILD_ROOT/%{apache_serverroot}/%{name}
%endif

%pre
# avoid fatal php errors, while we are changing files
# https://github.com/nextcloud
#
# We don't do this for new installs. Only for updates.
# If the first argument to pre is 1, the RPM operation is an initial installation. If the argument is 2, 
# the operation is an upgrade from an existing version to a new one.
if [ $1 -gt 1 -a ! -s %{statedir}/apache_stopped_during_nextcloud_install ]; then	
  echo "%{name} update: Checking for running Apache"
  # FIXME: this above should make it idempotent -- a requirement with openSUSE.
  # it does not work.
%if 0%{?suse_version} && 0
%if 0%{?suse_version} <= 1110
  rcapache2 status       | grep running > %{statedir}/apache_stopped_during_nextcloud_install
  rcapache2 stop
%else
  service apache2 status | grep running > %{statedir}/apache_stopped_during_nextcloud_install
  service apache2 stop
%endif
%endif
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
  service httpd status | grep running > %{statedir}/apache_stopped_during_nextcloud_install
  service httpd stop
%endif
fi
if [ -s %{statedir}/apache_stopped_during_nextcloud_install ]; then
  echo "%{name} pre-install: Stopping Apache"
fi

if [ $1 -eq 1 ]; then
    echo "%{name}-server: First install starting"
else
    echo "%{name}-server: installing upgrade ..."
fi
# https://github.com/nextcloud
if [ -x %{ocphp_bin}/php -a -f %{oc_dir}/occ ]; then
  echo "%{name}: occ maintenance:mode --on"
  su %{oc_user} -s /bin/sh -c "cd %{oc_dir}; PATH=%{ocphp_bin}:$PATH php ./occ maintenance:mode --on" || true
  echo yes > %{statedir}/occ_maintenance_mode_during_nextcloud_install
fi

%post
if [ $1 -eq 1 ]; then
    echo "%{name} First install complete"
else
    echo "%{name} Upgrade complete"
fi

%if 0%{?suse_version}
# make sure php5 is not in APACHE_MODULES, so that we don't create dups.
perl -pani -e 's@^(APACHE_MODULES=".*)\bphp5\b@$1@' /etc/sysconfig/apache2
# add php5 to APACHE_MODULES
perl -pani -e 's@^(APACHE_MODULES=")@${1}php5 @' /etc/sysconfig/apache2
%endif

if [ -s %{statedir}/apache_stopped_during_nextcloud_install ]; then
  echo "%{name} post-install: Restarting Apache"
  ## If we stopped apache in pre section, we now should restart. -- but *ONLY* then!
  ## Maybe delegate that task to occ upgrade? They also need to handle this, somehow.
%if 0%{?suse_version}
%if 0%{?suse_version} <= 1310
  rcapache2 start
%else
  rcapache2 restart apache2.service
%endif
%endif
%if 0%{?fedora_version} || 0%{?rhel_version} || 0%{?centos_version}
  service httpd start
%endif
fi

if [ -s %{statedir}/occ_maintenance_mode_during_nextcloud_install ]; then
echo "%{name}: occ upgrade"
su %{oc_user} -s /bin/sh -c "cd %{oc_dir}; PATH=%{ocphp_bin}:$PATH php ./occ upgrade" || true
echo "%{name}: occ maintenance:mode --off"
su %{oc_user} -s /bin/sh -c "cd %{oc_dir}; PATH=%{ocphp_bin}:$PATH php ./occ maintenance:mode --off" || true
fi

rm -f %{statedir}/apache_stopped_during_nextcloud_install
rm -f %{statedir}/occ_maintenance_mode_during_nextcloud_install

%files
%defattr(644,root,root,755)
%exclude %{apache_serverroot}/%{name}/README
%exclude %{apache_serverroot}/%{name}/README.SELinux
%doc README README.SELinux
%{apache_serverroot}/%{name}
%attr(-,wwwrun,www) %{apache_serverroot}/%{name}/occ
%config(noreplace) %{apache_confdir}/nextcloud.conf
%config(noreplace) %{apache_serverroot}/%{name}/.user.ini
%defattr(664,wwwrun,www,775)
%{apache_serverroot}/%{name}/apps
%defattr(660,wwwrun,www,770)
%{apache_serverroot}/%{name}/config
%{apache_serverroot}/%{name}/data

%changelog
* Thu Sep 28 2017 ecsos@opensuse.org
- fix boo#1036756: package security issue
* Mon Apr 24 2017 adamradovits12@hotmail.com
- upstream update to version 11.0.3
  * Server
  - Use the correct principal for shared addressbooks
  (server/3608)
  - Fix saving backup codes by using a correct data uri
  (server/3652)
  - Update icewind/streams to 0.5.2 (server/32931)
  - Fix string comparison and return docs (server/3665)
  - Typecast shared mount's storage_id to int as documented
    + some refactor to avoid similar bugs (server/3658)
  - Use a proper date format for transfer ownership
  (server/3700)
  - DAV sharing permissions should not depend on the order
  (server/3722)
  - Add new user agent of windows 10 dav backend
  (server/37641)
  - Add back appstoreenabled config switch (server/37671)
  - Call right function after sudo mode (server/3820)
  - Dont allow empty wildcard search (server/3842)
  - Remove single quotes around search query like in
  user search (server/3849)
  - Fix mimetype detection on public uploads for the
  workflow engine (server/3765)
  - Fix branding and show Nextcloud (server/39691)
  - Fix reshare with user activity message (server/39812)
  - Create correct VCard and return correct error codes
  (server/4029)
  - Prevent migration from ownCloud 10 to Nextcloud 11
  (server/34151)
  - Make sure transparency is an integer when saving a
  calendar (server/4167)
  - Make public links work with master key (server/42071)
  - Don't try to render the avatars if avatars are
  disabled (server/4214)
  - Reduce error message text (server/42281)
  - Don't list on public calendar endpoints (server/4229)
  - Fix upload of folders in Chrome (server/4154)
  - Make sure blob columns are correctly converted as
  parameters (server/4233)
  - Save the scope of an auth token in the session
  (server/4225)
  - Take share by mail into consideration if we calculate
  the access list (server/4242)
  - Also add the root of external storages to the file id
  list (server/4237)
  - Fix LDAP description (server/42382)
  - Remove the double password confirmation on changing
  cron (server/4236)
  - Fix scheduling plugin on legacy caldav endpoint
  (server/4235)
  - Directly fix invalid values of DTEND and DTSTART
  (server/4234)
  - Make JobList::next() lock free (server/4254)
  - Don't remove owner property for public calendars
  (server/4272)
  - Add capabilities for share by mail (server/42511)
  - Dont use the permissions mask while scanning
  (server/4278)
  - Add missing maintenance plugin to new DAV endpoint
  (server/4290)
  - Fix bug with shared_by for own calendars if shared
  (server/4301)
  - Translation string corrected > 1 user (server/4377)
  * Activity
  - Fix activities for "Files drop" on external storages
  (activity/118)
  * User_SAML
  - Bump to php-saml 2.10.5 (user_saml/1001)
  * Logreader
  - Small screen layout improvements
  (logreader/2bcd915969386ceb77c7f91dfd5fc19fd3212346
  - Fix log filtering
  (logreader/4095dfc62dcceb3c59a3f581baa5589737d0e6f3)
  - Greatly speedup log iteration
  (logreader/71a4c6849641f821e80d96674c57a69fe7a8aa9e)
  - Search more rows
  (logreader/b9d00b5599ac8a76862895266f1c23096391aad8)
  - Stop iterating if we dont have a valid file handle
  (logreader/a87a8e653ecae5efef6342e645b98f2878219c87)
  - Don't return a LogIterator on a broken handle
  (logreader/39069108f99d463b1cb8bc944f3ef24324b9f43d)
  - More robust log iteration
  (logreader/c0eb04d55bf1dee94ef523dae0e3b0e6afc272a6)
  - Use proper iso date format
  (logreader/13a31181a6d72d084797a71f49f2c5edee8c8dae)
  - Automatically try to fix some common escape errors from
  copy-pasted log entries
  (logreader/031db2a7f9b9f8cee42acf6eae7d993d31d4660a)
  - Fix stack trace parsing of incorrectly escaped logentries
  (logreader/538667770edfdd48374ef33e9c15498ed98ece60)
  - Highlight entries from the same request when clicking
  on an entry
  (logreader/2d1ccd0e4cca32220fcbe0b4d79d1cd23f0e73a5)
  - Fix copy paste info searchfield
  (logreader/0e91b2f46649a720feb7c3b6b8266b8657db5574)
  - Fix reset search after 0 results
  (logreader/50bec8ecf7edd81cfb96a35089283c0d879b41f3)
  - Allow searching for requestId and user
  (logreader/7f84e55bb4a1e4086ab0918a6bf58ad3885bbd91)
  - Allow searching in url
  (logreader/7833d97cf85fd351d2f7550d67d21bd0c2a815f4)
  - Fix infinite scroll
  (logreader/cbe874c6c068b9156ad8456edf31d112da40cbc9)
  - Dont show loading indicator if we already have entries
  (logreader/d26a08dc0540126177e8d20c3e243b44c5a399c4)
  * Gallery
  - Fix upload after core changes
  (gallery/b4ac4429841cfe2b7ea260dfb37fcde25580143c2)
  - Update JavaScript libraries (gallery/247)
* Thu Mar  2 2017 jengelh@inai.de
- Remove empty %%postun and redundant %%clean.
- Ensure summary/description is neutral.
* Tue Feb 28 2017 ecsos@opensuse.org
- upstream update to version 11.0.2
  * Server
  - Use login name to fix password confirm with ldap users
    (server/2953)
  - Change the row-format before changing the collation
    (server/3063)
  - Generate correct path for owner and use the display name
    (server/3080)
  - Markdown support for app descriptions (server/3117)
  - Fix style in comment (server/3143)
  - Escape the name for the jquery selector (server/3138)
  - Define spreed calls (server/3115)
  - LDAP Backend OCS Api (server/3213)
  - Fix Sharing app description (server/3397)
  - Fix shared-as-busy events for owner (server/3363)
  - Use correct theming when returning the defaults (server/3399)
  - Filter out sensitive appconfig values (server/3400)
  - Add transifex config for sharebymail (server/3423)
  - Update the email in the accounts table as well (server/3411)
  - Don't log the password on confirmPassword when LDAP throws an
    exception (server/3414)
  - Make sure ownCloud 8.2 activities also can get displayed
    (server/3412)
  - Popovermenu backport (server/3286)
  - Set vendor during install (server/3426)
  - Make sure the file information is available when sending the
    email (server/3433)
  - Add profile data to provisioning api (server/3259)
  - Fix detection of the new iOS app (server/3431)
  - Add integration tests for legacy DAV endpoints (server/3445)
  - Make sure invalid images don't flood the log file
    (server/3440)
  - Fix printing backup code (server/3510)
  - Fix cookie name (nctoken instead of octoken) (server/3511)
  - LDAP's checkPassword should only catch when a user was not
    found (server/3493)
  - Return unknown free space from nullstorage (server/3508)
  - Fix for address book data lost when any user receiving a
    share is deleted (server/3499)
  - Rename database password toggle (server/3500)
  - Popovermenu files css fix (server/3494)
  - Add screensharing icon (server/3481)
  - Fix misleading wording: searching is affected, not user
    access (server/3560)
  - Backport of Fix Broken UUID Attribute Detection (server/3528)
  * Activity
  - Make sure integer like names are still strings (activity/103)
  - Fix activities for public uploads (activity/113)
  - Show the parent as target when the file was not renamed
    (activity/114)
  - Fix activities for "Files drop" on external storages
    (activity/118)
  * SAML & SSO
  - Setup account later (user_saml/79)
  * Serverinfo
  - Fix SQL syntax error on MariaDB 10.0.27 and 10.1.19
    (serverinfo/77)
  - Don't throw an error when /proc/meminfo is not readable
    (serverinfo/76)
  * Survey_Client
  - Fix problem when checking size with dash in DB name
    (survey_client/50)
* Fri Jan 27 2017 guoyunhebrave@gmail.com
- Add php-openssl dependency
* Mon Jan 23 2017 ecsos@opensuse.org
- upstream update to version 11.0.1
* Wed Dec 14 2016 ecsos@opensuse.org
- upstream update to version 11.0.0
* Fri Sep 30 2016 ecsos@opensuse.org
- upstream update to version 10.0.1
* Sat Aug 27 2016 ecsos@opensuse.org
- upstream update to version 10.0.0
* Sun Aug  7 2016 chris@computersalat.de
- update spec file
  * osc service localrun format_spec_file
  * update Source with full URL
  * simplify deps mainly for openSUSE
* Sat Jul 23 2016 ecsos@opensuse.org
- enable HSTS to prevent the warning "The Strict-Transport-Security
  HTTP header is not configured" in admin-page
- turn maintenance:mode off after upgrade
* Thu Jul 21 2016 asemen@suse.de
- upstream update to version 9.0.53 (bsc#989998)
* Fri Jul  8 2016 ecsos@opensuse.org
- make apache_secure_data more restrictiver
- add missing .user.ini
- move README and README.SELinux to docdor to fix message code
  integrity check
* Tue Jul  5 2016 asemen@suse.de
- upstream update to version 9.0.52
* Fri Jul  1 2016 asemen@suse.de
- initial build nextcloud 9.0.51
